@@ -1,2 +1,2 @@
-drop table dbiv_test;
+drop table "dbiv_test";
 drop table comments_test;
\ No newline at end of file
